#!/bin/bash

my_path=$(pwd)
build_binary="qemu-arm"
host_type=$(lsb_release -c -s)
src_loc="http://git.linaro.org/git/qemu/qemu-linaro.git"
build_tmp=$(mktemp -d)
build_bin="${build_tmp}/arm-linux-user/${build_binary}"
bin_final="${my_path}/${host_type}/qemu-arm-static"
qemu_config_opts='--static --target-list=arm-linux-user'

error() { echo "$@" 1>&2; }
fail() { [ $# -eq 0 ] || error "$@"; rm -rf ${build_tmp}; exit 1; }

mkdir "${my_path}/${host_type}" 2> /dev/null 

for pkg in libglib2.0-dev git git-core zlib1g-dev
do
    sudo apt-get -y install $pkg
done


git_bin=$(which git) ||
	fail "Unable to find git binaries, please run 'apt-get install git'"

${git_bin} clone "${src_loc}" "${build_tmp}" || 
	fail "Unable to clone git source from $src_loc"

cd ${build_tmp}
./configure ${qemu_config_opts} ||
	fail "Failed to configure qemu"

make ||
	fail "Failed to make qemu"

[ -e "${build_bin}" ] || 
	fail "Did not find final binary at ${build_bin}"

cp ${build_bin} ${bin_final} ||
	fail "Failed to copy static binary from build path."

echo "Final binary found ${bin_final}"

cd ${my_path}
